@@ -6,19 +6,26 @@ CREDENTIALS_PATH = '../../../Secrets/YouTube'
 
 def test_get_metadata_01():
     easy_wrapper = YoutubeEasyWrapper()
-    easy_wrapper.initialize(credentials_path=CREDENTIALS_PATH)
+    easy_wrapper.initialize(api_key='AIzaSyCJnWnIAodBLmxvjo3eHz9XmLGMhcJ4-Hg')
     metadata = easy_wrapper.get_metadata(video_id='f3lUEnMaiAU')
     print(metadata['comments'][0])
 
 
 def test_get_metadata_02():
     easy_wrapper = YoutubeEasyWrapper()
-    easy_wrapper.initialize(credentials_path=CREDENTIALS_PATH)
+    easy_wrapper.initialize(api_key='AIzaSyCJnWnIAodBLmxvjo3eHz9XmLGMhcJ4-Hg')
     metadata = easy_wrapper.get_metadata(video_id='rdjnkb4ONWk')
     print(metadata['statistics']['likeCount'])
     assert metadata['title'] == 'The Pink Panther Show Episode 59 - Slink Pink'
 
 
+def test_get_metadata_03():
+    easy_wrapper = YoutubeEasyWrapper()
+    easy_wrapper.initialize(api_key='AIzaSyCJnWnIAodBLmxvjo3eHz9XmLGMhcJ4-Hg')
+    metadata = easy_wrapper.get_metadata(video_id='BW4fYZHVhfk')
+    print(metadata['statistics']['commentCount'])
+
+
 def test_search_videos_01():
     easy_wrapper = YoutubeEasyWrapper()
     easy_wrapper.initialize(credentials_path=CREDENTIALS_PATH)
@@ -34,3 +41,5 @@ def test_search_videos_02():
     results = easy_wrapper.search_videos(search_keyword='python', order='relevance')
     order_id = 1
     print(results[order_id]['video_id'])
+
+
